@@ -13,6 +13,7 @@ import concurrent.futures
 import cdsapi
 import requests
 from time import sleep
+import copy
 import urllib3
 urllib3.disable_warnings()
 
@@ -203,6 +204,7 @@ def time_request(from_date1, to_date1):
     else:
         years1 = np.arange(from_year, to_year+1)
         months1 = np.arange(1, 13)
+        days1 = np.arange(1, 32)
 
     days = ['{:02d}'.format(d) for d in days1]
     months = ['{:02d}'.format(m) for m in months1]
@@ -412,6 +414,10 @@ class CDS(object):
 
         ## Split dates into download chunks
         dates1 = pd.date_range(from_date1, to_date1, freq=freq_interval)
+
+        if dates1.empty:
+            raise ValueError('The frequency interval is too long for the input time period. Use a shorter frequency interval.')
+
         if from_date1 < dates1[0]:
             dates1 = pd.DatetimeIndex([from_date1]).append(dates1)
         if to_date1 > dates1[-1]:
@@ -429,15 +435,16 @@ class CDS(object):
                 dict1['pressure_level'] = [str(p) for p in pressure_levels1]
 
             for i, tdate in enumerate(dates1[1:]):
+                dict2 = copy.deepcopy(dict1)
                 fdate = dates1[i]
                 time_dict = time_request(fdate, tdate)
 
-                dict1.update(time_dict)
+                dict2.update(time_dict)
 
                 file_name = file_naming.format(param=p, from_date=fdate.strftime('%Y%m%d'), to_date=tdate.strftime('%Y%m%d'), product=product)
                 file_path = os.path.join(self.save_path, file_name)
 
-                req_list.append({'name': product, 'request': dict1, 'target': file_path})
+                req_list.append({'name': product, 'request': dict2, 'target': file_path})
 
         ## Run requests
         with concurrent.futures.ThreadPoolExecutor(max_workers=self.threads) as executor:
